import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)

/**
 * A rocket that can be controlled by the arrowkeys: up, left, right.
 * The gun is fired by hitting the 'space' key. 'z' releases a proton wave.
 * 
 * @author Poul Henriksen
 * @author Michael Kolling
 * 
 * @version 1.0
 */
public class Rocket extends SmoothMover
{
    private static final int gunReloadTime = 4;  
       // The minimum delay between firing the gun.
    private static final int protonReloadTime = 100;
    private int protonDelayCount;
    private int reloadDelayCount;   
            // How long ago we fired the gun the last time.
     
    private GreenfootImage rocket = new GreenfootImage("rocket.png");    
    private GreenfootImage rocketWithThrust = new GreenfootImage("rocketWithThrust.png");

    /**
     * Initilise this rocket.
     */
    public Rocket()
    {
        reloadDelayCount = 4;
        protonDelayCount = 300;
        int r = Greenfoot.getRandomNumber(360);
        int p = Greenfoot.getRandomNumber(3);
        this.setRotation(r);
        Vector v = new Vector(this.getRotation(), p);
        this.addForce(v);
        
    }

    /**
     * Do what a rocket's gotta do. (Which is: mostly flying about, and turning,
     * accelerating and shooting when the right keys are pressed.)
     */
    public void act()
    {
        Space w = (Space)getWorld();
        w.levelCount();
        move();
        checkKeys();
        reloadDelayCount++;
        protonDelayCount++;
        checkForCollision();
        
        
    }
    
    /**
     * check for collisions
     */
    private void checkForCollision()
    {
        Actor a = this.getOneIntersectingObject(Asteroid.class);
        
        if (a != null)
        {
            Space w = (Space) getWorld();
            Explosion e = new Explosion();
            w.addObject(e, this.getX(), this.getY());
            w.gameOver();
            w.removeObject(this);
            
            
        }
    }
    
    /**
     * Check whether there are any key pressed and react to them.
     */
    private void checkKeys() 
    {
        if (Greenfoot.isKeyDown("space")) 
        {
            fire();
        }
        if (Greenfoot.isKeyDown("left"))
        {
            turn(-5);
        }
        if (Greenfoot.isKeyDown("right"))
        {
            turn(5);
        }
        if (Greenfoot.isKeyDown("z"))
        {
            startProtonWave();
        }
        
        ignite(Greenfoot.isKeyDown("up"));
        igniteBreak(Greenfoot.isKeyDown("down"));
        
    }
    
    private void ignite(boolean thrusterOn)
    {
        if (thrusterOn)
        {
            this.setImage(rocketWithThrust);
            Vector v = new Vector(this.getRotation(), 0.1);
            this.addForce(v);
        }
    }
    private void igniteBreak(boolean thrusterOn)
    {
        if (thrusterOn)
        {
            this.setImage(rocket);
            Vector ve = new Vector(this.getRotation() -180, .125);
            this.addForce(ve);
            
        }
    }
    
    /**
     * Fire a bullet if the gun is ready.
     */
    private void fire() 
    {
        if (reloadDelayCount >= gunReloadTime) 
        {
            Bullet bullet = new Bullet (getMovement().copy(), getRotation());
            getWorld().addObject (bullet, getX(), getY());
            bullet.move ();
            reloadDelayCount = 0;
        }
        
    }
    
    public void startProtonWave()
    {
        if (protonDelayCount >= protonReloadTime)
        {
           Space w = (Space) getWorld();
           ProtonWave p = new ProtonWave();
           w.addObject(p, this.getX(), this.getY());
           protonDelayCount = 0;
        }
    }
    
}