import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)
import java.awt.Color;

/**
 * Space. Something for rockets to fly in.
 * 
 * @author Michael Kolling
 * @version 1.0
 */
public class Space extends World
{
    private Counter c;
    private int startAsteroids = 2;
    private int level = 0;
    Rocket rocket = new Rocket();
    
    
    public Space() 
    {
        super(600, 400, 1);
        GreenfootImage background = getBackground();
        background.setColor(Color.BLACK);
        background.fill();

        createStars(200);

        
        int r = Greenfoot.getRandomNumber(15);
        addObject(rocket, getWidth()/2 + r, getHeight()/2 + r);

        addAsteroids(startAsteroids);

        c = new Counter("Score: ");
        addObject(c, 60, 380);

        Explosion.initializeImages();
        ProtonWave.initializeImages();
        
        
    }
    
    public void levelCount()
    {
        while (getObjects(Asteroid.class).isEmpty() == true)
        {
            level++;
            rocket.setLocation(this.getWidth()/2, this.getHeight()/2);
            addAsteroids(startAsteroids + level);
            Greenfoot.playSound("hooray.wav");
            
        }
    }

    /**
     * Add a given number of asteroids to our world. Asteroids are only added into
     * the left half of the world.
     */
    private void addAsteroids(int count) 
    {
        for(int i = 0; i < count; i++) 
        {
            int x = Greenfoot.getRandomNumber(getWidth()/2);
            int y = Greenfoot.getRandomNumber(getHeight()/2);
            addObject(new Asteroid(), x, y);
        }
    }

    /**
     * Makes stars
     * @param numStars the number of stars you want to make
     */
    private void createStars(int numStars)
    {
        for (int i=0; i<200; i++)
        {
            GreenfootImage b = getBackground();
            b.setColor(Color.YELLOW);
            int x = Greenfoot.getRandomNumber(getWidth());
            int y = Greenfoot.getRandomNumber(getHeight());
            int z = Greenfoot.getRandomNumber(10);
            b.fillOval(x, y, z, z);
            
        }
    }

    /**
     * This method is called when the game is over to display the final score.
     */
    public void gameOver() 
    {
        // TODO: show the score board here. Currently missing.
        ScoreBoard s = new ScoreBoard(c.value);
        this.addObject(s, getWidth()/2, getHeight()/2);
        
    }
    
    public void addScore(int score)
    {
        c.add(score);
    }
    

}